@@ -39,31 +39,31 @@ func setupEnv(y *limayaml.LimaYAML) (map[string]string, error) {
 		upperVars[i] = strings.ToUpper(name)
 	}
 	if *y.PropagateProxyEnv {
-		localhostRegexes := []*regexp.Regexp{
-			regexp.MustCompile(`\blocalhost\b`),
-			regexp.MustCompile(`\b127.0.0.1\b`),
-		}
 		for _, name := range append(lowerVars, upperVars...) {
-			value, ok := os.LookupEnv(name)
-			if !ok {
-				continue
-			}
-			// Replace "localhost" in proxy settings with the gateway address
-			if name != "no_proxy" && name != "NO_PROXY" {
-				newValue := value
-				for _, re := range localhostRegexes {
-					newValue = re.ReplaceAllString(newValue, qemu.SlirpGateway)
-				}
-				if value != newValue {
-					logrus.Infof("Replacing %q value %q with %q", name, value, newValue)
-					value = newValue
+			if value, ok := os.LookupEnv(name); ok {
+				if _, ok := env[name]; ok && value != env[name] {
+					logrus.Infof("Overriding %q value %q with %q from limactl process environment",
+						name, env[name], value)
 				}
+				env[name] = value
 			}
-			if _, ok := env[name]; ok && value != env[name] {
-				logrus.Infof("Overriding %q value %q with %q from limactl process environment",
-					name, env[name], value)
+		}
+	}
+	// Replace "localhost" in proxy settings with the gateway address
+	localhostRegexes := []*regexp.Regexp{
+		regexp.MustCompile(`\blocalhost\b`),
+		regexp.MustCompile(`\b127.0.0.1\b`),
+	}
+	for _, name := range append(lowerVars, upperVars...) {
+		value, ok := env[name]
+		if ok && !strings.EqualFold(name, "no_proxy") {
+			for _, re := range localhostRegexes {
+				value = re.ReplaceAllString(value, qemu.SlirpGateway)
+			}
+			if value != env[name] {
+				logrus.Infof("Replacing %q value %q with %q", name, env[name], value)
+				env[name] = value
 			}
-			env[name] = value
 		}
 	}
 	// Make sure uppercase variants have the same value as lowercase ones.
@@ -96,13 +96,14 @@ func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort
 		return err
 	}
 	args := TemplateArgs{
-		Name:         name,
-		User:         u.Username,
-		UID:          uid,
-		Containerd:   Containerd{System: *y.Containerd.System, User: *y.Containerd.User},
-		SlirpNICName: qemu.SlirpNICName,
-		SlirpGateway: qemu.SlirpGateway,
-		SlirpDNS:     qemu.SlirpDNS,
+		Name:           name,
+		User:           u.Username,
+		UID:            uid,
+		Containerd:     Containerd{System: *y.Containerd.System, User: *y.Containerd.User},
+		SlirpNICName:   qemu.SlirpNICName,
+		SlirpGateway:   qemu.SlirpGateway,
+		SlirpDNS:       qemu.SlirpDNS,
+		SlirpIPAddress: qemu.SlirpIPAddress,
 	}
 
 	// change instance id on every boot so network config will be processed again
@@ -137,7 +138,7 @@ func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort
 	if err != nil {
 		return err
 	}
-	if *y.UseHostResolver {
+	if *y.HostResolver.Enabled {
 		args.UDPDNSLocalPort = udpDNSLocalPort
 		args.TCPDNSLocalPort = tcpDNSLocalPort
 		args.DNSAddresses = append(args.DNSAddresses, qemu.SlirpDNS)
