@@ -21,7 +21,7 @@ import (
 )
 
 func defaultContainerdArchives() []File {
-	const nerdctlVersion = "0.15.0"
+	const nerdctlVersion = "0.16.0"
 	location := func(goarch string) string {
 		return "https://github.com/containerd/nerdctl/releases/download/v" + nerdctlVersion + "/nerdctl-full-" + nerdctlVersion + "-linux-" + goarch + ".tar.gz"
 	}
@@ -29,12 +29,12 @@ func defaultContainerdArchives() []File {
 		{
 			Location: location("amd64"),
 			Arch:     X8664,
-			Digest:   "sha256:ca40d99d257e69f0220bb1cbdab1b602032692f45f713c901f328d2f4e3c12b3",
+			Digest:   "sha256:6dd955393fd781601a1cc7655d178fa539543f7a62f29e7c34a00e31ff4dddcf",
 		},
 		{
 			Location: location("arm64"),
 			Arch:     AARCH64,
-			Digest:   "sha256:dd8639ce868bab394467576f55375c4b40a8288badb579d2e30c3487da6004ea",
+			Digest:   "sha256:b342f6bec1bc0452148e9d8ec4afdf9de7b1e442e58e55fcf5330702e2fea62f",
 		},
 	}
 }
@@ -217,14 +217,36 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		// After defaults processing the singular HostPort and GuestPort values should not be used again.
 	}
 
-	if y.UseHostResolver == nil {
-		y.UseHostResolver = d.UseHostResolver
+	// If both `useHostResolved` and `HostResolver.Enabled` are defined in the same config,
+	// then the deprecated `useHostResolved` setting is silently ignored.
+	if y.HostResolver.Enabled == nil {
+		y.HostResolver.Enabled = y.UseHostResolver
 	}
-	if o.UseHostResolver != nil {
-		y.UseHostResolver = o.UseHostResolver
+	if d.HostResolver.Enabled == nil {
+		d.HostResolver.Enabled = d.UseHostResolver
 	}
-	if y.UseHostResolver == nil {
-		y.UseHostResolver = pointer.Bool(true)
+	if o.HostResolver.Enabled == nil {
+		o.HostResolver.Enabled = o.UseHostResolver
+	}
+
+	if y.HostResolver.Enabled == nil {
+		y.HostResolver.Enabled = d.HostResolver.Enabled
+	}
+	if o.HostResolver.Enabled != nil {
+		y.HostResolver.Enabled = o.HostResolver.Enabled
+	}
+	if y.HostResolver.Enabled == nil {
+		y.HostResolver.Enabled = pointer.Bool(true)
+	}
+
+	if y.HostResolver.IPv6 == nil {
+		y.HostResolver.IPv6 = d.HostResolver.IPv6
+	}
+	if o.HostResolver.IPv6 != nil {
+		y.HostResolver.IPv6 = o.HostResolver.IPv6
+	}
+	if y.HostResolver.IPv6 == nil {
+		y.HostResolver.IPv6 = pointer.Bool(false)
 	}
 
 	if y.PropagateProxyEnv == nil {
@@ -298,7 +320,12 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 	location := make(map[string]int)
 	for _, mount := range append(append(d.Mounts, y.Mounts...), o.Mounts...) {
 		if i, ok := location[mount.Location]; ok {
-			mounts[i].Writable = mount.Writable
+			if mount.SSHFS.FollowSymlinks != nil {
+				mounts[i].SSHFS.FollowSymlinks = mount.SSHFS.FollowSymlinks
+			}
+			if mount.Writable != nil {
+				mounts[i].Writable = mount.Writable
+			}
 		} else {
 			location[mount.Location] = len(mounts)
 			mounts = append(mounts, mount)
@@ -306,6 +333,16 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 	}
 	y.Mounts = mounts
 
+	for i := range y.Mounts {
+		mount := &y.Mounts[i]
+		if mount.SSHFS.FollowSymlinks == nil {
+			mount.SSHFS.FollowSymlinks = pointer.Bool(false)
+		}
+		if mount.Writable == nil {
+			mount.Writable = pointer.Bool(false)
+		}
+	}
+
 	// Note: DNS lists are not combined; highest priority setting is picked
 	if len(y.DNS) == 0 {
 		y.DNS = d.DNS
