@@ -67,7 +67,10 @@ func TestFillDefault(t *testing.T) {
 		Video: Video{
 			Display: pointer.String("none"),
 		},
-		UseHostResolver:   pointer.Bool(true),
+		HostResolver: HostResolver{
+			Enabled: pointer.Bool(true),
+			IPv6:    pointer.Bool(false),
+		},
 		PropagateProxyEnv: pointer.Bool(true),
 	}
 
@@ -116,6 +119,8 @@ func TestFillDefault(t *testing.T) {
 
 	expect := builtin
 	expect.Mounts = y.Mounts
+	expect.Mounts[0].Writable = pointer.Bool(false)
+	expect.Mounts[0].SSHFS.FollowSymlinks = pointer.Bool(false)
 	// Only missing Mounts field is Writable, and the default value is also the null value: false
 
 	expect.Provision = y.Provision
@@ -184,13 +189,16 @@ func TestFillDefault(t *testing.T) {
 		Video: Video{
 			Display: pointer.String("cocoa"),
 		},
-		UseHostResolver:   pointer.Bool(false),
+		HostResolver: HostResolver{
+			Enabled: pointer.Bool(false),
+			IPv6:    pointer.Bool(true),
+		},
 		PropagateProxyEnv: pointer.Bool(false),
 
 		Mounts: []Mount{
 			{
 				Location: "/var/log",
-				Writable: false,
+				Writable: pointer.Bool(false),
 			},
 		},
 		Provision: []Provision{
@@ -235,6 +243,7 @@ func TestFillDefault(t *testing.T) {
 	expect = d
 	// Also verify that archive arch is filled in
 	expect.Containerd.Archives[0].Arch = *d.Arch
+	expect.Mounts[0].SSHFS.FollowSymlinks = pointer.Bool(false)
 
 	y = LimaYAML{}
 	FillDefault(&y, &d, &LimaYAML{}, filePath)
@@ -295,13 +304,17 @@ func TestFillDefault(t *testing.T) {
 		Video: Video{
 			Display: pointer.String("cocoa"),
 		},
-		UseHostResolver:   pointer.Bool(false),
+		HostResolver: HostResolver{
+			Enabled: pointer.Bool(false),
+			IPv6:    pointer.Bool(false),
+		},
 		PropagateProxyEnv: pointer.Bool(false),
 
 		Mounts: []Mount{
 			{
 				Location: "/var/log",
-				Writable: true,
+				Writable: pointer.Bool(true),
+				SSHFS:    SSHFS{FollowSymlinks: pointer.Bool(true)},
 			},
 		},
 		Provision: []Provision{
@@ -357,7 +370,8 @@ func TestFillDefault(t *testing.T) {
 
 	// o.Mounts just makes d.Mounts[0] writable because the Location matches
 	expect.Mounts = append(d.Mounts, y.Mounts...)
-	expect.Mounts[0].Writable = true
+	expect.Mounts[0].Writable = pointer.Bool(true)
+	expect.Mounts[0].SSHFS.FollowSymlinks = pointer.Bool(true)
 
 	// o.Networks[1] is overriding the d.Networks[0].Lima entry for the "def0" interface
 	expect.Networks = append(append(d.Networks, y.Networks...), o.Networks[0])
