@@ -25,7 +25,8 @@ type LimaYAML struct {
 	Network           NetworkDeprecated `yaml:"network,omitempty" json:"network,omitempty"` // DEPRECATED, use `networks` instead
 	Env               map[string]string `yaml:"env,omitempty" json:"env,omitempty"`
 	DNS               []net.IP          `yaml:"dns,omitempty" json:"dns,omitempty"`
-	UseHostResolver   *bool             `yaml:"useHostResolver,omitempty" json:"useHostResolver,omitempty"`
+	HostResolver      HostResolver      `yaml:"hostResolver,omitempty" json:"hostResolver,omitempty"`
+	UseHostResolver   *bool             `yaml:"useHostResolver,omitempty" json:"useHostResolver,omitempty"` // DEPRECATED, use `HostResolver.Enabled` instead
 	PropagateProxyEnv *bool             `yaml:"propagateProxyEnv,omitempty" json:"propagateProxyEnv,omitempty"`
 }
 
@@ -44,7 +45,12 @@ type File struct {
 
 type Mount struct {
 	Location string `yaml:"location" json:"location"` // REQUIRED
-	Writable bool   `yaml:"writable,omitempty" json:"writable,omitempty"`
+	Writable *bool  `yaml:"writable,omitempty" json:"writable,omitempty"`
+	SSHFS    SSHFS  `yaml:"sshfs,omitempty" json:"sshfs,omitempty"`
+}
+
+type SSHFS struct {
+	FollowSymlinks *bool `yaml:"followSymlinks,omitempty" json:"followSymlinks,omitempty"`
 }
 
 type SSH struct {
@@ -127,6 +133,11 @@ type Network struct {
 	Interface  string `yaml:"interface,omitempty" json:"interface,omitempty"`
 }
 
+type HostResolver struct {
+	Enabled *bool `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	IPv6    *bool `yaml:"ipv6,omitempty" json:"ipv6,omitempty"`
+}
+
 // DEPRECATED types below
 
 // Types have been renamed to turn all references to the old names into compiler errors,
